r"""
 _                            
| |                          ████████╗██████╗  █████╗ ██╗  ██╗
| |_ ___ _ __  ___  ___  _ __╚══██╔══╝██╔══██╗██╔══██╗╚██╗██╔╝
| __/ _ \ '_ \/ __|/ _ \| '__|  ██║   ██████╔╝███████║ ╚███╔╝ 
| ||  __/ | | \__ \ (_) | |     ██║   ██╔══██╗██╔══██║ ██╔██╗ 
 \__\___|_| |_|___/\___/|_|     ██║   ██║  ██║██║  ██║██╔╝ ██╗
                                ╚═╝   ╚═╝  ╚═╝╚═╝  ╚═╝╚═╝  ╚═╝  
"""

from . import _linalg as linalg
from ._math_tensor import (
    sin,
    cos,
    tan,
    sinh,
    cosh,
    tanh,
    exp,
    log,
    log10,
    dot,
    ddot,
    trace,
    transpose,
    sum,
    sqrt,
    einsum,
    matmul,
    diagonal,
    ravel,
)
from . import _math_array as array
